package com.google.android.vending.licensing;

import android.content.Context;
import android.util.Log;
import java.net.URI;
import java.net.URISyntaxException;
import java.util.HashMap;
import java.util.Map;
import java.util.Vector;
import org.apache.http.NameValuePair;
import org.apache.http.client.utils.URLEncodedUtils;

public class APKExpansionPolicy implements Policy {
    private static final String DEFAULT_MAX_RETRIES = "0";
    private static final String DEFAULT_RETRY_COUNT = "0";
    private static final String DEFAULT_RETRY_UNTIL = "0";
    private static final String DEFAULT_VALIDITY_TIMESTAMP = "0";
    public static final int MAIN_FILE_URL_INDEX = 0;
    private static final long MILLIS_PER_MINUTE = 60000;
    public static final int PATCH_FILE_URL_INDEX = 1;
    private static final String PREFS_FILE = "com.android.vending.licensing.APKExpansionPolicy";
    private static final String PREF_LAST_RESPONSE = "lastResponse";
    private static final String PREF_MAX_RETRIES = "maxRetries";
    private static final String PREF_RETRY_COUNT = "retryCount";
    private static final String PREF_RETRY_UNTIL = "retryUntil";
    private static final String PREF_VALIDITY_TIMESTAMP = "validityTimestamp";
    private static final String TAG = "APKExpansionPolicy";
    private Vector<String> mExpansionFileNames;
    private Vector<Long> mExpansionFileSizes;
    private Vector<String> mExpansionURLs;
    private int mLastResponse;
    private long mLastResponseTime;
    private long mMaxRetries;
    private PreferenceObfuscator mPreferences;
    private long mRetryCount;
    private long mRetryUntil;
    private long mValidityTimestamp;

    public APKExpansionPolicy(Context context, Obfuscator obfuscator) {
        this.mLastResponseTime = 0;
        this.mExpansionURLs = new Vector();
        this.mExpansionFileNames = new Vector();
        this.mExpansionFileSizes = new Vector();
        this.mPreferences = new PreferenceObfuscator(context.getSharedPreferences(PREFS_FILE, MAIN_FILE_URL_INDEX), obfuscator);
        this.mLastResponse = Integer.parseInt(this.mPreferences.getString(PREF_LAST_RESPONSE, Integer.toString(Policy.RETRY)));
        this.mValidityTimestamp = Long.parseLong(this.mPreferences.getString(PREF_VALIDITY_TIMESTAMP, DEFAULT_VALIDITY_TIMESTAMP));
        this.mRetryUntil = Long.parseLong(this.mPreferences.getString(PREF_RETRY_UNTIL, DEFAULT_VALIDITY_TIMESTAMP));
        this.mMaxRetries = Long.parseLong(this.mPreferences.getString(PREF_MAX_RETRIES, DEFAULT_VALIDITY_TIMESTAMP));
        this.mRetryCount = Long.parseLong(this.mPreferences.getString(PREF_RETRY_COUNT, DEFAULT_VALIDITY_TIMESTAMP));
    }

    private Map<String, String> decodeExtras(String str) {
        Map<String, String> hashMap = new HashMap();
        try {
            for (NameValuePair nameValuePair : URLEncodedUtils.parse(new URI("?" + str), "UTF-8")) {
                Object name = nameValuePair.getName();
                int i = MAIN_FILE_URL_INDEX;
                while (hashMap.containsKey(name)) {
                    i += PATCH_FILE_URL_INDEX;
                    name = nameValuePair.getName() + i;
                }
                hashMap.put(name, nameValuePair.getValue());
            }
        } catch (URISyntaxException e) {
            Log.w(TAG, "Invalid syntax error while decoding extras data from server.");
        }
        return hashMap;
    }

    private void setLastResponse(int i) {
        this.mLastResponseTime = System.currentTimeMillis();
        this.mLastResponse = i;
        this.mPreferences.putString(PREF_LAST_RESPONSE, Integer.toString(i));
    }

    private void setMaxRetries(String str) {
        Long valueOf;
        try {
            valueOf = Long.valueOf(Long.parseLong(str));
        } catch (NumberFormatException e) {
            Log.w(TAG, "Licence retry count (GR) missing, grace period disabled");
            str = DEFAULT_VALIDITY_TIMESTAMP;
            valueOf = Long.valueOf(0);
        }
        this.mMaxRetries = valueOf.longValue();
        this.mPreferences.putString(PREF_MAX_RETRIES, str);
    }

    private void setRetryCount(long j) {
        this.mRetryCount = j;
        this.mPreferences.putString(PREF_RETRY_COUNT, Long.toString(j));
    }

    private void setRetryUntil(String str) {
        Long valueOf;
        try {
            valueOf = Long.valueOf(Long.parseLong(str));
        } catch (NumberFormatException e) {
            Log.w(TAG, "License retry timestamp (GT) missing, grace period disabled");
            str = DEFAULT_VALIDITY_TIMESTAMP;
            valueOf = Long.valueOf(0);
        }
        this.mRetryUntil = valueOf.longValue();
        this.mPreferences.putString(PREF_RETRY_UNTIL, str);
    }

    private void setValidityTimestamp(String str) {
        Long valueOf;
        try {
            valueOf = Long.valueOf(Long.parseLong(str));
        } catch (NumberFormatException e) {
            Log.w(TAG, "License validity timestamp (VT) missing, caching for a minute");
            valueOf = Long.valueOf(MILLIS_PER_MINUTE + System.currentTimeMillis());
            str = Long.toString(valueOf.longValue());
        }
        this.mValidityTimestamp = valueOf.longValue();
        this.mPreferences.putString(PREF_VALIDITY_TIMESTAMP, str);
    }

    public boolean allowAccess() {
        return true;
    }

    public String getExpansionFileName(int i) {
        return i < this.mExpansionFileNames.size() ? (String) this.mExpansionFileNames.elementAt(i) : null;
    }

    public long getExpansionFileSize(int i) {
        return i < this.mExpansionFileSizes.size() ? ((Long) this.mExpansionFileSizes.elementAt(i)).longValue() : -1;
    }

    public String getExpansionURL(int i) {
        return i < this.mExpansionURLs.size() ? (String) this.mExpansionURLs.elementAt(i) : null;
    }

    public int getExpansionURLCount() {
        return this.mExpansionURLs.size();
    }

    public long getMaxRetries() {
        return this.mMaxRetries;
    }

    public long getRetryCount() {
        return this.mRetryCount;
    }

    public long getRetryUntil() {
        return this.mRetryUntil;
    }

    public long getValidityTimestamp() {
        return this.mValidityTimestamp;
    }

    public void processServerResponse(int i, ResponseData responseData) {
        if (i != Policy.RETRY) {
            setRetryCount(0);
        } else {
            setRetryCount(1 + this.mRetryCount);
        }
        if (i == Policy.LICENSED) {
            Map decodeExtras = decodeExtras(responseData.extra);
            this.mLastResponse = i;
            setValidityTimestamp(Long.toString(MILLIS_PER_MINUTE + System.currentTimeMillis()));
            for (String str : decodeExtras.keySet()) {
                if (str.equals("VT")) {
                    setValidityTimestamp((String) decodeExtras.get(str));
                } else if (str.equals("GT")) {
                    setRetryUntil((String) decodeExtras.get(str));
                } else if (str.equals("GR")) {
                    setMaxRetries((String) decodeExtras.get(str));
                } else if (str.startsWith("FILE_URL")) {
                    setExpansionURL(Integer.parseInt(str.substring("FILE_URL".length())) - 1, (String) decodeExtras.get(str));
                } else if (str.startsWith("FILE_NAME")) {
                    setExpansionFileName(Integer.parseInt(str.substring("FILE_NAME".length())) - 1, (String) decodeExtras.get(str));
                } else if (str.startsWith("FILE_SIZE")) {
                    setExpansionFileSize(Integer.parseInt(str.substring("FILE_SIZE".length())) - 1, Long.parseLong((String) decodeExtras.get(str)));
                }
            }
        } else if (i == Policy.NOT_LICENSED) {
            setValidityTimestamp(DEFAULT_VALIDITY_TIMESTAMP);
            setRetryUntil(DEFAULT_VALIDITY_TIMESTAMP);
            setMaxRetries(DEFAULT_VALIDITY_TIMESTAMP);
        }
        setLastResponse(i);
        this.mPreferences.commit();
    }

    public void resetPolicy() {
        this.mPreferences.putString(PREF_LAST_RESPONSE, Integer.toString(Policy.RETRY));
        setRetryUntil(DEFAULT_VALIDITY_TIMESTAMP);
        setMaxRetries(DEFAULT_VALIDITY_TIMESTAMP);
        setRetryCount(Long.parseLong(DEFAULT_VALIDITY_TIMESTAMP));
        setValidityTimestamp(DEFAULT_VALIDITY_TIMESTAMP);
        this.mPreferences.commit();
    }

    public void setExpansionFileName(int i, String str) {
        if (i >= this.mExpansionFileNames.size()) {
            this.mExpansionFileNames.setSize(i + PATCH_FILE_URL_INDEX);
        }
        this.mExpansionFileNames.set(i, str);
    }

    public void setExpansionFileSize(int i, long j) {
        if (i >= this.mExpansionFileSizes.size()) {
            this.mExpansionFileSizes.setSize(i + PATCH_FILE_URL_INDEX);
        }
        this.mExpansionFileSizes.set(i, Long.valueOf(j));
    }

    public void setExpansionURL(int i, String str) {
        if (i >= this.mExpansionURLs.size()) {
            this.mExpansionURLs.setSize(i + PATCH_FILE_URL_INDEX);
        }
        this.mExpansionURLs.set(i, str);
    }
}
