package com.google.android.vending.licensing;

import android.text.TextUtils;
import android.util.Log;
import com.google.android.vending.licensing.util.Base64;
import com.google.android.vending.licensing.util.Base64DecoderException;
import java.security.InvalidKeyException;
import java.security.PublicKey;
import java.security.Signature;

class LicenseValidator {
    private static final int ERROR_CONTACTING_SERVER = 257;
    private static final int ERROR_INVALID_PACKAGE_NAME = 258;
    private static final int ERROR_NON_MATCHING_UID = 259;
    private static final int ERROR_NOT_MARKET_MANAGED = 3;
    private static final int ERROR_OVER_QUOTA = 5;
    private static final int ERROR_SERVER_FAILURE = 4;
    private static final int LICENSED = 0;
    private static final int LICENSED_OLD_KEY = 2;
    private static final int NOT_LICENSED = 1;
    private static final String SIGNATURE_ALGORITHM = "SHA1withRSA";
    private static final String TAG = "LicenseValidator";
    private final LicenseCheckerCallback mCallback;
    private final DeviceLimiter mDeviceLimiter;
    private final int mNonce;
    private final String mPackageName;
    private final Policy mPolicy;
    private final String mVersionCode;

    LicenseValidator(Policy policy, DeviceLimiter deviceLimiter, LicenseCheckerCallback licenseCheckerCallback, int i, String str, String str2) {
        this.mPolicy = policy;
        this.mDeviceLimiter = deviceLimiter;
        this.mCallback = licenseCheckerCallback;
        this.mNonce = i;
        this.mPackageName = str;
        this.mVersionCode = str2;
    }

    private void handleApplicationError(int i) {
        this.mCallback.applicationError(i);
    }

    private void handleInvalidResponse() {
        this.mCallback.dontAllow(Policy.NOT_LICENSED);
    }

    private void handleResponse(int i, ResponseData responseData) {
        this.mPolicy.processServerResponse(i, responseData);
        if (this.mPolicy.allowAccess()) {
            this.mCallback.allow(i);
        } else {
            this.mCallback.dontAllow(i);
        }
    }

    public LicenseCheckerCallback getCallback() {
        return this.mCallback;
    }

    public int getNonce() {
        return this.mNonce;
    }

    public String getPackageName() {
        return this.mPackageName;
    }

    public void verify(PublicKey publicKey, int i, String str, String str2) {
        String str3 = null;
        ResponseData parse;
        if (i == 0 || i == NOT_LICENSED || i == LICENSED_OLD_KEY) {
            try {
                Signature instance = Signature.getInstance(SIGNATURE_ALGORITHM);
                instance.initVerify(publicKey);
                if (str == null) {
                    Log.e(TAG, "Signature verification failed.");
                    handleInvalidResponse();
                    return;
                }
                instance.update(str.getBytes());
                if (instance.verify(Base64.decode(str2))) {
                    try {
                        parse = ResponseData.parse(str);
                        if (parse.responseCode != i) {
                            Log.e(TAG, "Response codes don't match.");
                            handleInvalidResponse();
                            return;
                        } else if (parse.nonce != this.mNonce) {
                            Log.e(TAG, "Nonce doesn't match.");
                            handleInvalidResponse();
                            return;
                        } else if (!parse.packageName.equals(this.mPackageName)) {
                            Log.e(TAG, "Package name doesn't match.");
                            handleInvalidResponse();
                            return;
                        } else if (parse.versionCode.equals(this.mVersionCode)) {
                            str3 = parse.userId;
                            if (TextUtils.isEmpty(str3)) {
                                Log.e(TAG, "User identifier is empty.");
                                handleInvalidResponse();
                                return;
                            }
                        } else {
                            Log.e(TAG, "Version codes don't match.");
                            handleInvalidResponse();
                            return;
                        }
                    } catch (IllegalArgumentException e) {
                        Log.e(TAG, "Could not parse response.");
                        handleInvalidResponse();
                        return;
                    }
                }
                Log.e(TAG, "Signature verification failed.");
                handleInvalidResponse();
                return;
            } catch (Throwable e2) {
                throw new RuntimeException(e2);
            } catch (InvalidKeyException e3) {
                handleApplicationError(ERROR_OVER_QUOTA);
                return;
            } catch (Throwable e22) {
                throw new RuntimeException(e22);
            } catch (Base64DecoderException e4) {
                Log.e(TAG, "Could not Base64-decode signature.");
                handleInvalidResponse();
                return;
            }
        }
        parse = null;
        switch (i) {
            case LICENSED /*0*/:
            case LICENSED_OLD_KEY /*2*/:
                handleResponse(this.mDeviceLimiter.isDeviceAllowed(str3), parse);
            case NOT_LICENSED /*1*/:
                handleResponse(Policy.NOT_LICENSED, parse);
            case ERROR_NOT_MARKET_MANAGED /*3*/:
                handleApplicationError(ERROR_NOT_MARKET_MANAGED);
            case ERROR_SERVER_FAILURE /*4*/:
                Log.w(TAG, "An error has occurred on the licensing server.");
                handleResponse(Policy.RETRY, parse);
            case ERROR_OVER_QUOTA /*5*/:
                Log.w(TAG, "Licensing server is refusing to talk to this device, over quota.");
                handleResponse(Policy.RETRY, parse);
            case ERROR_CONTACTING_SERVER /*257*/:
                Log.w(TAG, "Error contacting licensing server.");
                handleResponse(Policy.RETRY, parse);
            case ERROR_INVALID_PACKAGE_NAME /*258*/:
                handleApplicationError(NOT_LICENSED);
            case ERROR_NON_MATCHING_UID /*259*/:
                handleApplicationError(LICENSED_OLD_KEY);
            default:
                Log.e(TAG, "Unknown response code for license check.");
                handleInvalidResponse();
        }
    }
}
