package com.google.android.vending.licensing;

import WTpNJi1.hTWTZgD2PZWB;
import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.content.ServiceConnection;
import android.content.pm.PackageManager.NameNotFoundException;
import android.os.Handler;
import android.os.HandlerThread;
import android.os.IBinder;
import android.util.Log;
import com.google.android.vending.licensing.ILicenseResultListener.Stub;
import com.google.android.vending.licensing.util.Base64;
import com.google.android.vending.licensing.util.Base64DecoderException;
import java.security.KeyFactory;
import java.security.PublicKey;
import java.security.SecureRandom;
import java.security.spec.X509EncodedKeySpec;
import java.util.HashSet;
import java.util.LinkedList;
import java.util.Queue;
import java.util.Set;

public class LicenseChecker implements ServiceConnection {
    private static final boolean DEBUG_LICENSE_ERROR = false;
    private static final String KEY_FACTORY_ALGORITHM = "RSA";
    private static final SecureRandom RANDOM;
    private static final String TAG = "LicenseChecker";
    private static final int TIMEOUT_MS = 10000;
    private final Set<LicenseValidator> mChecksInProgress;
    private final Context mContext;
    private Handler mHandler;
    private final String mPackageName;
    private final Queue<LicenseValidator> mPendingChecks;
    private final Policy mPolicy;
    private PublicKey mPublicKey;
    private ILicensingService mService;
    private final String mVersionCode;

    private class ResultListener extends Stub {
        private static final int ERROR_CONTACTING_SERVER = 257;
        private static final int ERROR_INVALID_PACKAGE_NAME = 258;
        private static final int ERROR_NON_MATCHING_UID = 259;
        private Runnable mOnTimeout;
        private final LicenseValidator mValidator;

        /* renamed from: com.google.android.vending.licensing.LicenseChecker.ResultListener.1 */
        class C01201 implements Runnable {
            final /* synthetic */ LicenseChecker val$this$0;

            C01201(LicenseChecker licenseChecker) {
                this.val$this$0 = licenseChecker;
            }

            public void run() {
                Log.i(LicenseChecker.TAG, "Check timed out.");
                LicenseChecker.this.handleServiceConnectionError(ResultListener.this.mValidator);
                LicenseChecker.this.finishCheck(ResultListener.this.mValidator);
            }
        }

        /* renamed from: com.google.android.vending.licensing.LicenseChecker.ResultListener.2 */
        class C01212 implements Runnable {
            final /* synthetic */ int val$responseCode;
            final /* synthetic */ String val$signature;
            final /* synthetic */ String val$signedData;

            C01212(int i, String str, String str2) {
                this.val$responseCode = i;
                this.val$signedData = str;
                this.val$signature = str2;
            }

            public void run() {
                Log.i(LicenseChecker.TAG, "Received response.");
                if (LicenseChecker.this.mChecksInProgress.contains(ResultListener.this.mValidator)) {
                    ResultListener.this.clearTimeout();
                    ResultListener.this.mValidator.verify(LicenseChecker.this.mPublicKey, this.val$responseCode, this.val$signedData, this.val$signature);
                    LicenseChecker.this.finishCheck(ResultListener.this.mValidator);
                }
            }
        }

        public ResultListener(LicenseValidator licenseValidator) {
            this.mValidator = licenseValidator;
            this.mOnTimeout = new C01201(LicenseChecker.this);
            startTimeout();
        }

        private void clearTimeout() {
            Log.i(LicenseChecker.TAG, "Clearing timeout.");
            LicenseChecker.this.mHandler.removeCallbacks(this.mOnTimeout);
        }

        private void startTimeout() {
            Log.i(LicenseChecker.TAG, "Start monitoring timeout.");
            LicenseChecker.this.mHandler.postDelayed(this.mOnTimeout, 10000);
        }

        public void verifyLicense(int i, String str, String str2) {
            LicenseChecker.this.mHandler.post(new C01212(i, str, str2));
        }
    }

    static {
        RANDOM = new SecureRandom();
    }

    public LicenseChecker(Context context, Policy policy, String str) {
        this.mChecksInProgress = new HashSet();
        this.mPendingChecks = new LinkedList();
        this.mContext = context;
        this.mPolicy = policy;
        this.mPublicKey = generatePublicKey(str);
        this.mPackageName = this.mContext.getPackageName();
        this.mVersionCode = getVersionCode(context, this.mPackageName);
        HandlerThread handlerThread = new HandlerThread("background thread");
        handlerThread.start();
        this.mHandler = new Handler(handlerThread.getLooper());
    }

    private void cleanupService() {
        if (this.mService != null) {
            try {
                this.mContext.unbindService(this);
            } catch (IllegalArgumentException e) {
                Log.e(TAG, "Unable to unbind from licensing service (already unbound)");
            }
            this.mService = null;
        }
    }

    private void finishCheck(LicenseValidator licenseValidator) {
        synchronized (this) {
            this.mChecksInProgress.remove(licenseValidator);
            if (this.mChecksInProgress.isEmpty()) {
                cleanupService();
            }
        }
    }

    private int generateNonce() {
        return RANDOM.nextInt();
    }

    private static PublicKey generatePublicKey(String str) {
        try {
            return KeyFactory.getInstance(KEY_FACTORY_ALGORITHM).generatePublic(new X509EncodedKeySpec(Base64.decode(str)));
        } catch (Throwable e) {
            throw new RuntimeException(e);
        } catch (Throwable e2) {
            Log.e(TAG, "Could not decode from Base64.");
            throw new IllegalArgumentException(e2);
        } catch (Throwable e22) {
            Log.e(TAG, "Invalid key specification.");
            throw new IllegalArgumentException(e22);
        }
    }

    private static String getVersionCode(Context context, String str) {
        try {
            return String.valueOf(hTWTZgD2PZWB.GqQ0y6m5BHIOW60q(context.getPackageManager(), str, 0).versionCode);
        } catch (NameNotFoundException e) {
            Log.e(TAG, "Package not found. could not get version code.");
            return "";
        }
    }

    private void handleServiceConnectionError(LicenseValidator licenseValidator) {
        synchronized (this) {
            this.mPolicy.processServerResponse(Policy.RETRY, null);
            if (this.mPolicy.allowAccess()) {
                licenseValidator.getCallback().allow(Policy.RETRY);
            } else {
                licenseValidator.getCallback().dontAllow(Policy.RETRY);
            }
        }
    }

    private void runChecks() {
        while (true) {
            LicenseValidator licenseValidator = (LicenseValidator) this.mPendingChecks.poll();
            if (licenseValidator != null) {
                try {
                    Log.i(TAG, "Calling checkLicense on service for " + licenseValidator.getPackageName());
                    this.mService.checkLicense((long) licenseValidator.getNonce(), licenseValidator.getPackageName(), new ResultListener(licenseValidator));
                    this.mChecksInProgress.add(licenseValidator);
                } catch (Throwable e) {
                    Log.w(TAG, "RemoteException in checkLicense call.", e);
                    handleServiceConnectionError(licenseValidator);
                }
            } else {
                return;
            }
        }
    }

    public void checkAccess(LicenseCheckerCallback licenseCheckerCallback) {
        synchronized (this) {
            if (this.mPolicy.allowAccess()) {
                Log.i(TAG, "Using cached license response");
                licenseCheckerCallback.allow(Policy.LICENSED);
            } else {
                LicenseValidator licenseValidator = new LicenseValidator(this.mPolicy, new NullDeviceLimiter(), licenseCheckerCallback, generateNonce(), this.mPackageName, this.mVersionCode);
                if (this.mService == null) {
                    Log.i(TAG, "Binding to licensing service.");
                    try {
                        if (this.mContext.bindService(new Intent(new String(Base64.decode("Y29tLmFuZHJvaWQudmVuZGluZy5saWNlbnNpbmcuSUxpY2Vuc2luZ1NlcnZpY2U="))), this, 1)) {
                            this.mPendingChecks.offer(licenseValidator);
                        } else {
                            Log.e(TAG, "Could not bind to service.");
                            handleServiceConnectionError(licenseValidator);
                        }
                    } catch (SecurityException e) {
                        licenseCheckerCallback.applicationError(6);
                    } catch (Base64DecoderException e2) {
                        e2.printStackTrace();
                    }
                } else {
                    this.mPendingChecks.offer(licenseValidator);
                    runChecks();
                }
            }
        }
    }

    public void onDestroy() {
        synchronized (this) {
            cleanupService();
            this.mHandler.getLooper().quit();
        }
    }

    public void onServiceConnected(ComponentName componentName, IBinder iBinder) {
        synchronized (this) {
            this.mService = ILicensingService.Stub.asInterface(iBinder);
            runChecks();
        }
    }

    public void onServiceDisconnected(ComponentName componentName) {
        synchronized (this) {
            Log.w(TAG, "Service unexpectedly disconnected.");
            this.mService = null;
        }
    }
}
